@@ -1,7 +1,7 @@
 # These are done in a specific format to prevent circular imports
 # Think of them as an escalation from base component to most complex
 from .component import Component
-from .connection import Connection
+from .connection import Connection, ConnectionPath
 from .device import Device
 from .layer import Layer
 from .params import Params
